Group
============================

.. currentmodule:: alfred3_interact.group

.. autoclass:: Group
   :show-inheritance:




   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
      :toctree:




      ~Group.active_members


      ~Group.active_other_members


      ~Group.chat


      ~Group.deactivate


      ~Group.members


      ~Group.other_members


      ~Group.takes_members







   .. rubric:: Attributes

   .. autosummary::
      :template: autosummary/attribute.rst
      :toctree:


         ~Group.finished
         ~Group.full
         ~Group.group_id
         ~Group.me
         ~Group.nactive
         ~Group.nfinished
         ~Group.shared_data
         ~Group.spec_name
         ~Group.you
